from setuptools import setup

setup(
    name='simplearraysumVT',
    version='0.1.0',    
    description='Calculate the sum of array',
    url='https://github.com/VankaTaganai/simplearraysumVT',
    author='Ivan Panov',
    author_email='panovivan01@yandex.ru',
    packages=['simplearraysumVT'],
)
